from enum import Enum


class ReservationType(Enum):
    ""
    INDIVIDUAL = 'S'  # 'INDIVIDUAL'
    "Individual reservation type."
    ILT_CLASS = 'C'  # 'ILT_CLASS'
    "ILT class"
    TEAM = 'T'  # 'TEAM'
    "Team"
    INSTRUCTOR = 'I'  # 'INSTRUCTOR'
    "Instructor"


class ReservationScope(Enum):
    "Reservation scope."
    RELEVANT = 'RELEVANT'
    "Relevant to caller, i.e. reservations associated with you in context to user role."
    ALL = 'ALL'
    "All reservations."
    COMMUNITY = 'COMMUNITY'
    "Relevant to the community."
    CLASS = 'CLASS'
    "Relevant to your class."


class InitConfig(Enum):
    "Initial configuration."
    NONE = 'N'
    "No configs loaded."
    LAST = 'L'
    "Load last saved config (if any)."
    EXERCISE = 'E'
    "Load default for exercise (if any)."
